@@ -12,10 +12,10 @@ import pickle
 import re
 import subprocess
 
-from calkit.models import ProjectStatus
-
 import requests
 
+from calkit.models import ProjectStatus
+
 try:
     from datetime import UTC
 except ImportError:
@@ -107,9 +107,12 @@ def load_calkit_info(
                 for obj_name, obj in info[kind].items():
                     if "_include" in obj:
                         include_fpath = obj.pop("_include")
-                        with open(include_fpath) as f:
-                            include_data = ryaml.load(f)
-                        info[kind][obj_name] |= include_data
+                        if wdir is not None:
+                            include_fpath = os.path.join(wdir, include_fpath)
+                        if os.path.isfile(include_fpath):
+                            with open(include_fpath) as f:
+                                include_data = ryaml.load(f)
+                            info[kind][obj_name] |= include_data
     if as_pydantic:
         return ProjectInfo.model_validate(info)
     return info
@@ -417,3 +420,22 @@ def get_latest_project_status(wdir: str = None) -> ProjectStatus | None:
     statuses = get_project_status_history(wdir=wdir)
     if statuses:
         return statuses[-1]
+
+
+def detect_project_name(wdir: str = None) -> str:
+    """Detect a Calkit project owner and name."""
+    ck_info = load_calkit_info(wdir=wdir)
+    name = ck_info.get("name")
+    owner = ck_info.get("owner")
+    if name is None or owner is None:
+        try:
+            url = Repo(path=wdir).remote().url
+        except ValueError:
+            raise ValueError("No Git remote set with name 'origin'")
+        from_url = url.split("github.com")[-1][1:].removesuffix(".git")
+        owner_name, project_name = from_url.split("/")
+    if name is None:
+        name = project_name
+    if owner is None:
+        owner = owner_name
+    return f"{owner}/{name}"
